pub struct ZwlrOutputHeadV1 { /* private fields */ }
Available on crate feature wayland and Linux only.
output device

A head is an output device. The difference between a wl_output object and a head is that heads are advertised even if they are turned off. A head object only advertises properties and cannot be used directly to change them.

A head has some read-only properties: modes, name, description and physical_size. These cannot be changed by clients.

Other properties can be updated via a wlr_output_configuration object.

Properties sent via this interface are applied atomically via the wlr_output_manager.done event. No guarantees are made regarding the order in which properties are sent.

See also the Request enum for this interface.

Implementations



impl ZwlrOutputHeadV1

pub fn name(&self, name: String)

head name

This event describes the head name.

The naming convention is compositor defined, but limited to alphanumeric characters and dashes (-). Each name is unique among all wlr_output_head objects, but if a wlr_output_head object is destroyed the same name may be reused later. The names will also remain consistent across sessions with the same hardware and software configuration.

Examples of names include ‘HDMI-A-1’, ‘WL-1’, ‘X11-1’, etc. However, do not assume that the name is a reflection of an underlying DRM connector, X11 connection, etc.

If this head matches a wl_output, the wl_output.name event must report the same name.

The name event is sent after a wlr_output_head object is created. This event is only sent once per object, and the name does not change over the lifetime of the wlr_output_head object.

pub fn description(&self, description: String)

head description

This event describes a human-readable description of the head.

The description is a UTF-8 string with no convention defined for its contents. Examples might include ‘Foocorp 11“ Display’ or ‘Virtual X11 output via :1’. However, do not assume that the name is a reflection of the make, model, serial of the underlying DRM connector or the display name of the underlying X11 connection, etc.

If this head matches a wl_output, the wl_output.description event must report the same name.

The description event is sent after a wlr_output_head object is created. This event is only sent once per object, and the description does not change over the lifetime of the wlr_output_head object.

pub fn physical_size(&self, width: i32, height: i32)

head physical size

This event describes the physical size of the head. This event is only sent if the head has a physical size (e.g. is not a projector or a virtual device).

The physical size event is sent after a wlr_output_head object is created. This event is only sent once per object, and the physical size does not change over the lifetime of the wlr_output_head object.

pub fn mode(&self, mode: &ZwlrOutputModeV1)

introduce a mode

This event introduces a mode for this head. It is sent once per supported mode.

pub fn enabled(&self, enabled: i32)

head is enabled or disabled

This event describes whether the head is enabled. A disabled head is not mapped to a region of the global compositor space.

When a head is disabled, some properties (current_mode, position, transform and scale) are irrelevant.

pub fn current_mode(&self, mode: &ZwlrOutputModeV1)

current mode

This event describes the mode currently in use for this head. It is only sent if the output is enabled.

pub fn position(&self, x: i32, y: i32)

current position

This events describes the position of the head in the global compositor space. It is only sent if the output is enabled.

pub fn transform(&self, transform: Transform)

current transformation

This event describes the transformation currently applied to the head. It is only sent if the output is enabled.

pub fn scale(&self, scale: f64)

current scale

This events describes the scale of the head in the global compositor space. It is only sent if the output is enabled.

pub fn finished(&self)

the head has disappeared

This event indicates that the head is no longer available. The head object becomes inert. Clients should send a destroy request and release any resources associated with it.

pub fn make(&self, make: String)

head manufacturer

This event describes the manufacturer of the head.

Together with the model and serial_number events the purpose is to allow clients to recognize heads from previous sessions and for example load head-specific configurations back.

It is not guaranteed this event will be ever sent. A reason for that can be that the compositor does not have information about the make of the head or the definition of a make is not sensible in the current setup, for example in a virtual session. Clients can still try to identify the head by available information from other events but should be aware that there is an increased risk of false positives.

If sent, the make event is sent after a wlr_output_head object is created and only sent once per object. The make does not change over the lifetime of the wlr_output_head object.

It is not recommended to display the make string in UI to users. For that the string provided by the description event should be preferred.

pub fn model(&self, model: String)

head model

This event describes the model of the head.

Together with the make and serial_number events the purpose is to allow clients to recognize heads from previous sessions and for example load head-specific configurations back.

It is not guaranteed this event will be ever sent. A reason for that can be that the compositor does not have information about the model of the head or the definition of a model is not sensible in the current setup, for example in a virtual session. Clients can still try to identify the head by available information from other events but should be aware that there is an increased risk of false positives.

If sent, the model event is sent after a wlr_output_head object is created and only sent once per object. The model does not change over the lifetime of the wlr_output_head object.

It is not recommended to display the model string in UI to users. For that the string provided by the description event should be preferred.

pub fn serial_number(&self, serial_number: String)

head serial number

This event describes the serial number of the head.

Together with the make and model events the purpose is to allow clients to recognize heads from previous sessions and for example load head- specific configurations back.

It is not guaranteed this event will be ever sent. A reason for that can be that the compositor does not have information about the serial number of the head or the definition of a serial number is not sensible in the current setup. Clients can still try to identify the head by available information from other events but should be aware that there is an increased risk of false positives.

If sent, the serial number event is sent after a wlr_output_head object is created and only sent once per object. The serial number does not change over the lifetime of the wlr_output_head object.

It is not recommended to display the serial_number string in UI to users. For that the string provided by the description event should be preferred.

pub fn adaptive_sync(&self, state: AdaptiveSyncState)

current adaptive sync state

This event describes whether adaptive sync is currently enabled for the head or not. Adaptive sync is also known as Variable Refresh Rate or VRR.